import invoke from 'react-native-webview-invoke/browser'

/*
* 检测是否app环境
* @name isNative
* @return true app环境,false 非app环境
*/
export const isNative = () => {
	if(!window) return false;
	const userAgent = window.navigator.userAgent;
	if(userAgent.indexOf('QB/NATIVE')>-1) return true;
	if(userAgent.toLocaleLowerCase().indexOf('native')) return true;
	return false;
};

/*
* 拍摄照片
* @name takePhoto
* @详情参考 https://github.com/react-native-image-picker/react-native-image-picker
* @params opt{
* 	mediaType: 'photo' or 'video'
* 	maxWidth: To resize the image
* 	maxHeight: To resize the image
* 	videoQuality: 'low', 'medium', or 'high' on iOS, 'low' or 'high' on Android
* 	durationLimit: Video max duration in seconds
* 	quality: 0 to 1, photos
* 	includeBase64: If true, creates base64 string of the image (Avoid using on large image files due to performance)
* 	saveToPhotos: (Boolean) Only for launchCamera, saves the image/video file captured to public photo
* }
* @return {
* 	didCancel: true if the user cancelled the process
* 	errorCode: camera_unavailable/permission/others
* 	errorMessage: Description of the error, use it for debug purpose only
* 	base64: The base64 string of the image (photos only)
* 	uri: The uri to the local file on the device (uri might change for same file for different session so don't save it)
* 	width: Image dimensions (photos only)
* 	height: Image dimensions (photos only)
* 	fileSize: The file size (photos only)
* 	type: The file type (photos only)
* 	fileName: The file name
* }
*/
export const takePhoto = async (opt) => {
	return new Promise(async (resolve) => {
		// invoke.define('takePhoto', async (data) => {resolve(data)});
		invoke.define('takePhotoCompleted', async (result) => {resolve(result)});
		await invoke.bind("takePhoto")(opt)
	})
};

export const recordVideo = async (opt) => {
	return new Promise(async (resolve) => {
		// invoke.define('recordVideo', async (data) => {resolve(data)});
		invoke.define('recordVideoCompleted', async (result) => {resolve(result)});
		await invoke.bind("recordVideo")(opt)
	})
};

/*
* 扫描二维码
* @name barCodeScan
* @return
*/
export const barCodeScan = async (opt) => {
	return new Promise(async (resolve) => {
		// invoke.define('barCodeScan', async (data) => {resolve(data)});
		invoke.define('barCodeScanCompleted', async (result) => {resolve(result)});
		await invoke.bind("barCodeScan")(opt)
	})
};

/*
* 打开新的WebView
* @name openWindow
* @return
*/
export const openWindow = async (opt) => {
	return new Promise(async (resolve) => {
		// invoke.define('openWindow', async (data) => {resolve(data)});
		await invoke.bind("openWindow")(opt)
	})
};

/*
* 关闭当前的WebView
* @name closeWindow
* @return
*/
export const closeWindow = async (opt) => {
	return new Promise(async (resolve) => {
		// invoke.define('closeWindow', async (data) => {resolve(data)});
		await invoke.bind("closeWindow")(opt)
	})
};

/*
* 获取坐标信息
* @name getPosition
* @return
*/
export const getPosition = async (opt) => {
	return new Promise(async (resolve) => {
		// invoke.define('getPosition', async (data) => {resolve(data)});
		invoke.define('getPositionCompleted', async (result) => {resolve(result)});
		await invoke.bind("getPosition")(opt)
	})
};

/*
* 使用重庆电子签章
* @name launchCQDigitalSign
* @return
*/
export const launchCQDigitalSign = async (opt) => {
	return new Promise(async (resolve) => {
		// invoke.define('launchCQDigitalSign', async (data) => {resolve(data)});
		invoke.define('launchCQDigitalSignCompleted', async (result) => {resolve(result)});
		await invoke.bind("launchCQDigitalSign")(opt)
	})
};

/*
* 使用手写板签名
* @name launchFingerSign
* @return
*/
export const launchFingerSign = async (opt) => {
	return new Promise(async (resolve) => {
		// invoke.define('launchFingerSign', async (data) => {resolve(data)});
		invoke.define('launchFingerSignCompleted', async (result) => {resolve(result)});
		await invoke.bind("launchFingerSign")(opt)
	})
};

/*
* 社交应用分享
* @name launchShare
* @return
*/
export const launchShare = async (opt) => {
	return new Promise(async (resolve) => {
		// invoke.define('launchShare', async (data) => {resolve(data)});
		invoke.define('launchShareCompleted', async (result) => {resolve(result)});
		await invoke.bind("launchShare")(opt)
	})
};

/*
* 获取token
* @name getToken
* @return
*/
export const getToken = async () => {
	return new Promise(async (resolve) => {
		// invoke.define('getToken', async () => {resolve()});
		invoke.define('getTokenCompleted', async (result) => {resolve(result)});
		await invoke.bind("getToken")()
	})
};

export const previewImage = async (opt) => {
	return new Promise(async (resolve) => {
		await invoke.bind("previewImage")(opt)
	})
};

/*
*  获取上传图片以及文件的token
*  options: {
*  		id,  --必输项，如果是项目级应用则设置project_id,否则设置user_id
*  		app_id="common",  --逻辑必输项，设置为应用的code，如果没有设置系统默认为common，
*  		signature=true,  --是否需要签名访问
*  		rename=true,  --文件是否重命名
*  		maxSize=1024*1024*10  --文件尺寸限制，默认为10M
*  	}
*/
export const getUpToken = async (opt) => {
	return new Promise(async (resolve) => {
		invoke.define('getUpTokenCompleted', async (result) => {resolve(result)});
		await invoke.bind("getUpToken")(opt)
	})
};

/*
* @name uploadImage 上传图片
* options {
*     token: object,  --从getUpToken中获取
*     photo: object,  --选择或拍照的结果，主要会用到fileName,type,fileName，多数情况直接拿结果直接用就行了
*     onProgress: func,  --图片上传的进度回调
* }
 */
export const uploadImage = async (opt) => {
	return new Promise(async (resolve) => {
		invoke.define('uploadImageCompleted', async (result) => {resolve(result)});
		await invoke.bind("uploadImage")(opt)
	})
};



/*
* @name uploadImageThrough 图片直传，获取token和上传操作合并
* options {
*     photo: object,  --选择或拍照的结果，主要会用到fileName,type,fileName，多数情况直接拿结果直接用就行了
*     tokenMode: string,  --必输项，project or user
*     appId: string,  --所属的app代码，默认为common
*     signature: false,  --是否需要签名上传
*     rename=true,   --是否重命名
*     maxSize=1024*10000  --最大尺寸
* }
 */
export const uploadImageThrough = async (opt) => {
	return new Promise(async (resolve) => {
		invoke.define('uploadImageThroughCompleted', async (result) => {resolve(result)});
		await invoke.bind("uploadImageThrough")(opt)
	})
};

/*
* @name takePhotoAndUpload 拍照后直接上传
* options {
*     quality: 0.6,
*     includeBase64: true,
*     saveToPhotos: false,
*     uploadOptions: {
*         tokenMode: string,  --必输项，project or user，默认为project
*         appId: string,  --所属的app代码，默认为common
*         signature: false,  --是否需要签名上传
*     }  --图片上传的options
* }
 */
export const takePhotoAndUpload = async (opt) => {
	return new Promise(async (resolve) => {
		invoke.define('takePhotoAndUploadCompleted', async (result) => {resolve(result)});
		await invoke.bind("takePhotoAndUpload")(opt)
	})
};

/*
* @name choosePhotoAndUpload 选择文件后上传
* options {
*     includeBase64: false,
*     uploadOptions: {
*         tokenMode: string,  --必输项，project or user
*         appId: string,  --所属的app代码，默认为common
*         signature: false,  --是否需要签名上传
*     }  --图片上传的options
* }
 */
export const choosePhotoAndUpload = async (opt) => {
	return new Promise(async (resolve) => {
		invoke.define('choosePhotoAndUploadCompleted', async (result) => {resolve(result)});
		await invoke.bind("choosePhotoAndUpload")(opt)
	})
};

/*
* @name getPhotoAndUpload 拍照或选择文件后上传
* options {
*     sourceType  --['album', 'camera']相册选择和摄像头的选择，可二者同时
*     takeOptions: {
*         quality: 0.6,
*         includeBase64: true,
*         saveToPhotos: false,
*     }  --拍照的options，无特殊情况几乎不用设置
*     chooseOptions:{
*         includeBase64: true,
*     }  --拍照的options，无特殊情况几乎不用设置
*     uploadOptions: {
*         tokenMode: string,  --归类方式 project or user，默认project
*         appId: string,  --所属的app代码，默认为common，建议输入
*         signature: true,  --是否需要签名上传，默认为true
*     }  --图片上传的options
* }
 */
export const getPhotoAndUpload = async (opt) => {
	return new Promise(async (resolve) => {
		invoke.define('getPhotoAndUploadCompleted', async (result) => {resolve(result)});
		await invoke.bind("getPhotoAndUpload")(opt)
	})
};



export const EVENTS_TYPE = {
	keyboardWillShow: 'keyboardWillShow', // 键盘即将出现
	keyboardDidShow: 'keyboardDidShow', // 键盘已经出现
	keyboardDidHide: 'keyboardDidHide', // 键盘已经隐藏
	keyboardWillHide: 'keyboardWillHide', // 键盘即将隐藏
	appStateChange: 'appStateChange', // app前后台切换
	aliPushMessage: 'aliPushMessage', // 阿里云推送监听
};

export default {
	isNative,
	takePhoto,
	recordVideo,
	barCodeScan,
	openWindow,
	closeWindow,
	getPosition,
	launchCQDigitalSign,
	launchFingerSign,
	launchShare,
	getToken,

	previewImage,
	getUpToken,
	uploadImage,
	uploadImageThrough,
	takePhotoAndUpload,
	choosePhotoAndUpload,
	getPhotoAndUpload,
}


